if_nametoindex

Function if_nametoindex 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn if_nametoindex(name: *const c_char) -> c_uint
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/if_nametoindex.html.

Safety

Compares the name to a constant string and only returns an int as a result. An invalid name string will return an index of 0