#[unsafe(no_mangle)]pub unsafe extern "C" fn if_nameindex() -> *const if_nameindexExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/if_nameindex.html.
Safety
Returns a constant pointer to a pre defined const stub list The end of the list is determined by an if_nameindex struct having if_index 0 and if_name NULL